# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
from uhd_restpy.base import Base
from uhd_restpy.files import Files


class Render(Base):
    """
    The Render class encapsulates a required render resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = 'render'
    _SDM_ATT_MAP = {
        'Enabled': 'enabled',
        'LastUpdate': 'lastUpdate',
        'RenderJson': 'renderJson',
    }

    def __init__(self, parent):
        super(Render, self).__init__(parent)

    @property
    def Enabled(self):
        """
        Returns
        -------
        - bool: Indicates whether the client should render the view, if false the image from the step will be rendered
        """
        return self._get_attribute(self._SDM_ATT_MAP['Enabled'])
    @Enabled.setter
    def Enabled(self, value):
        self._set_attribute(self._SDM_ATT_MAP['Enabled'], value)

    @property
    def LastUpdate(self):
        """
        Returns
        -------
        - str: timestamp of the last update which requires client side refresh
        """
        return self._get_attribute(self._SDM_ATT_MAP['LastUpdate'])

    @property
    def RenderJson(self):
        """
        Returns
        -------
        - str: Rendering data as json blob
        """
        return self._get_attribute(self._SDM_ATT_MAP['RenderJson'])
    @RenderJson.setter
    def RenderJson(self, value):
        self._set_attribute(self._SDM_ATT_MAP['RenderJson'], value)

    def update(self, Enabled=None, RenderJson=None):
        """Updates render resource on the server.

        Args
        ----
        - Enabled (bool): Indicates whether the client should render the view, if false the image from the step will be rendered
        - RenderJson (str): Rendering data as json blob

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))
